@@ -8,6 +8,7 @@ module Test.Hspec.Expectations (
 , shouldBe
 , shouldSatisfy
 , shouldContain
+, shouldMatchList
 , shouldReturn
 
 -- * Expecting exceptions
@@ -36,11 +37,10 @@ module Test.Hspec.Expectations (
 , errorCall
 ) where
 
-import           Prelude
 import           Test.HUnit (Assertion, (@?=), assertBool, assertFailure)
 import           Control.Exception
 import           Data.Typeable
-import           Data.List (isInfixOf)
+import           Data.List ((\\), isInfixOf)
 
 type Expectation = Assertion
 
@@ -48,7 +48,7 @@ type Expectation = Assertion
 expectationFailure :: String -> Expectation
 expectationFailure = assertFailure
 
-infix 1 `shouldBe`, `shouldSatisfy`, `shouldReturn`, `shouldThrow`
+infix 1 `shouldBe`, `shouldSatisfy`, `shouldContain`, `shouldMatchList`, `shouldReturn`, `shouldThrow`
 
 -- |
 -- @actual \`shouldBe\` expected@ sets the expectation that @actual@ is equal
@@ -69,6 +69,14 @@ list `shouldContain` sublist = assertBool errorMsg (sublist `isInfixOf` list)
   where
     errorMsg = show list ++ " doesn't contain " ++ show sublist
 
+-- |
+-- @xs \`shouldMatchList\` ys@ sets the expectation that @xs@ has the same
+-- elements that @ys@ has, possibly in another order
+shouldMatchList :: (Show a, Eq a) => [a] -> [a] -> Expectation
+xs `shouldMatchList` ys = assertBool errorMsg (all null [xs \\ ys, ys \\ xs])
+  where
+    errorMsg = show ys ++ " is not a permutation of " ++ show xs
+
 -- |
 -- @action \`shouldReturn\` expected@ sets the expectation that @action@
 -- returns @expected@.
